@@ -15,6 +15,9 @@ OC.L10N.register(
     "Completed" : "Yemmed",
     "Open details" : "Ldi talqayt",
     "Details" : "Talqayt",
+    "General" : "Amatu",
+    "Appearance" : "Udem",
+    "Search" : "Nadi",
     "Sharing" : "Beṭṭu",
     "Tags" : "Tibzimin",
     "Activity" : "Armud",
@@ -26,19 +29,19 @@ OC.L10N.register(
     "Modified" : "Yettwabeddel",
     "Created" : "Yettwarna.",
     "Comments" : "Commentaires",
-    "Save" : "Sekles",
     "Cancel reply" : "Semmet tiririt.",
     "Reply" : "Err",
     "Description" : "Aglam",
     "Open link" : "Nɣel aseɣwen",
-    "Keyboard shortcuts" : "Inegzumen n unasiw",
-    "Ctrl" : "Ctrl",
-    "Search" : "Nadi",
+    "seconds ago" : "Tasinin aya",
     "Cancel edit" : "Sefsex aseẓreg",
     "No notifications" : "Ulac tisezmal",
     "Close" : "Mdel",
     "Share" : "Bḍu",
     "Personal" : "Udmawan",
+    "Save" : "Sekles",
+    "Keyboard shortcuts" : "Inegzumen n unasiw",
+    "Ctrl" : "Ctrl",
     "Today" : "Ass-a"
 },
 "nplurals=2; plural=(n != 1);");
