@@ -112,7 +112,7 @@ OC.L10N.register(
     "Later" : "稍後處理",
     "copy" : "複製",
     "Read more inside" : "您可以在裡面深入了解更多",
-    "Custom lists - click to rename!" : "自定義清單 - 點擊以重新命名！",
+    "Custom lists - click to rename!" : "自訂清單 - 點擊以重新命名！",
     "To Do" : "待辦",
     "In Progress" : "進行中",
     "Done" : "完成",
@@ -290,8 +290,8 @@ OC.L10N.register(
     "Select Date" : "選擇日期",
     "Later today – {timeLocale}" : "今天稍後 – {timeLocale}",
     "Set due date for later today" : "設定今天稍後的到期日",
-    "Tomorrow – {timeLocale}" : "明天 – {timeLocale}",
-    "Set due date for tomorrow" : "設定明天的到期日",
+    "Tomorrow – {timeLocale}" : "明日 – {timeLocale}",
+    "Set due date for tomorrow" : "設定截止日期為明日",
     "This weekend – {timeLocale}" : "本週末 – {timeLocale}",
     "Set due date for this weekend" : "設定本週末的到期日",
     "Next week – {timeLocale}" : "下星期 – {timeLocale}",
@@ -388,7 +388,7 @@ OC.L10N.register(
     "Close" : "關閉",
     "No upcoming cards" : "沒有快將到期的卡片",
     "upcoming cards today" : "今天接下來的卡片",
-    "upcoming cards tomorrow" : "明天接下來的卡片",
+    "upcoming cards tomorrow" : "明日的即將到來的卡片",
     "upcoming cards" : "快將到期的卡片",
     "New card" : "新卡片",
     "Link to a board" : "連結到面板",
