@@ -1,31 +1,15 @@
 <?php
+
 /**
- * @copyright Copyright (c) 2018 Julius Härtl <jus@bitgrid.net>
- *
- * @copyright Copyright (c) 2019 Alexandru Puiu <alexpuiu20@yahoo.com>
- *
- * @author Julius Härtl <jus@bitgrid.net>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2018 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Deck\Activity;
 
 use OCA\Deck\Db\Acl;
+use OCA\Deck\Service\CardService;
+use OCA\Deck\Service\CirclesService;
 use OCP\Activity\IEvent;
 use OCP\Activity\IProvider;
 use OCP\Comments\IComment;
@@ -35,7 +19,6 @@ use OCP\IConfig;
 use OCP\IURLGenerator;
 use OCP\IUserManager;
 use OCP\L10N\IFactory;
-use OCA\Deck\Service\CardService;
 
 class DeckProvider implements IProvider {
 
@@ -56,7 +39,10 @@ class DeckProvider implements IProvider {
 	/** @var CardService */
 	private $cardService;
 
-	public function __construct(IURLGenerator $urlGenerator, ActivityManager $activityManager, IUserManager $userManager, ICommentsManager $commentsManager, IFactory $l10n, IConfig $config, $userId, CardService $cardService) {
+	/** @var CirclesService */
+	private $circlesService;
+
+	public function __construct(IURLGenerator $urlGenerator, ActivityManager $activityManager, IUserManager $userManager, ICommentsManager $commentsManager, IFactory $l10n, IConfig $config, $userId, CardService $cardService, CirclesService $circlesService) {
 		$this->userId = $userId;
 		$this->urlGenerator = $urlGenerator;
 		$this->activityManager = $activityManager;
@@ -65,6 +51,7 @@ class DeckProvider implements IProvider {
 		$this->l10nFactory = $l10n;
 		$this->config = $config;
 		$this->cardService = $cardService;
+		$this->circlesService = $circlesService;
 	}
 
 	/**
@@ -77,7 +64,7 @@ class DeckProvider implements IProvider {
 	 * @throws \InvalidArgumentException Should be thrown if your provider does not know this event
 	 * @since 11.0.0
 	 */
-	public function parse($language, IEvent $event, IEvent $previousEvent = null): IEvent {
+	public function parse($language, IEvent $event, ?IEvent $previousEvent = null): IEvent {
 		if ($event->getApp() !== 'deck') {
 			throw new \InvalidArgumentException();
 		}
@@ -105,18 +92,29 @@ class DeckProvider implements IProvider {
 				'user' => [
 					'type' => 'user',
 					'id' => $author,
-					'name' => $user !== null ? $user->getDisplayName() : $author
+					'name' => $user->getDisplayName()
 				],
 			];
 			$event->setAuthor($author);
+		} else {
+			$params = [
+				'user' => [
+					'type' => 'user',
+					'id' => 'deleted_users',
+					'name' => 'deleted_users',
+				]
+			];
 		}
 		if ($event->getObjectType() === ActivityManager::DECK_OBJECT_BOARD) {
+			if (!$this->activityManager->canSeeBoardActivity($event->getObjectId(), $event->getAffectedUser())) {
+				throw new \InvalidArgumentException();
+			}
 			if (isset($subjectParams['board']) && $event->getObjectName() === '') {
 				$event->setObject($event->getObjectType(), $event->getObjectId(), $subjectParams['board']['title']);
 			}
 			$board = [
 				'type' => 'highlight',
-				'id' => $event->getObjectId(),
+				'id' => (string)$event->getObjectId(),
 				'name' => $event->getObjectName(),
 				'link' => $this->deckUrl('/board/' . $event->getObjectId()),
 			];
@@ -125,17 +123,20 @@ class DeckProvider implements IProvider {
 		}
 
 		if (isset($subjectParams['card']) && $event->getObjectType() === ActivityManager::DECK_OBJECT_CARD) {
+			if (!$this->activityManager->canSeeCardActivity($event->getObjectId(), $event->getAffectedUser())) {
+				throw new \InvalidArgumentException();
+			}
 			if ($event->getObjectName() === '') {
 				$event->setObject($event->getObjectType(), $event->getObjectId(), $subjectParams['card']['title']);
 			}
 			$card = [
 				'type' => 'highlight',
-				'id' => $event->getObjectId(),
+				'id' => (string)$event->getObjectId(),
 				'name' => $event->getObjectName(),
 			];
 
 			if (array_key_exists('board', $subjectParams)) {
-				$card['link'] = $this->cardService->getRedirectUrlForCard($event->getObjectId());
+				$card['link'] = $this->cardService->getCardUrl($event->getObjectId());
 				$event->setLink($card['link']);
 			}
 			$params['card'] = $card;
@@ -217,7 +218,7 @@ class DeckProvider implements IProvider {
 		if (array_key_exists($paramName, $subjectParams)) {
 			$params[$paramName] = [
 				'type' => 'highlight',
-				'id' => $subjectParams[$paramName]['id'],
+				'id' => (string)$subjectParams[$paramName]['id'],
 				'name' => $subjectParams[$paramName]['title'],
 				'link' => $this->deckUrl('/board/' . $subjectParams[$paramName]['id'] . '/'),
 			];
@@ -228,7 +229,7 @@ class DeckProvider implements IProvider {
 		if (array_key_exists($paramName, $subjectParams)) {
 			$params[$paramName] = [
 				'type' => 'highlight',
-				'id' => $subjectParams[$paramName]['id'],
+				'id' => (string)$subjectParams[$paramName]['id'],
 				'name' => $subjectParams[$paramName]['title'],
 			];
 		}
@@ -239,7 +240,7 @@ class DeckProvider implements IProvider {
 		if (array_key_exists($paramName, $subjectParams)) {
 			$params[$paramName] = [
 				'type' => 'highlight',
-				'id' => $subjectParams[$paramName]['id'],
+				'id' => (string)$subjectParams[$paramName]['id'],
 				'name' => $subjectParams[$paramName]['data'],
 				'link' => $this->urlGenerator->linkToRoute('deck.attachment.display', ['cardId' => $subjectParams['card']['id'], 'attachmentId' => $subjectParams['attachment']['id']]),
 			];
@@ -263,7 +264,7 @@ class DeckProvider implements IProvider {
 		if (array_key_exists('label', $subjectParams)) {
 			$params['label'] = [
 				'type' => 'highlight',
-				'id' => $subjectParams['label']['id'],
+				'id' => (string)$subjectParams['label']['id'],
 				'name' => $subjectParams['label']['title']
 			];
 		}
@@ -279,10 +280,21 @@ class DeckProvider implements IProvider {
 					'id' => $subjectParams['acl']['participant'],
 					'name' => $user !== null ? $user->getDisplayName() : $subjectParams['acl']['participant']
 				];
-			} else {
+			} elseif ($subjectParams['acl']['type'] === Acl::PERMISSION_TYPE_CIRCLE) {
+				$circle = $this->circlesService->getCircle($subjectParams['acl']['participant']);
+
+				// suppressing psalm because $circle is typed as Circle|null but psalm doesnt know about the OCA class
+				// $circle->getName() will be defined when $circle is not null
+				/** @psalm-suppress UndefinedMethod */
 				$params['acl'] = [
 					'type' => 'highlight',
 					'id' => $subjectParams['acl']['participant'],
+					'name' => $circle ? $circle->getName() : $subjectParams['acl']['participant']
+				];
+			} else {
+				$params['acl'] = [
+					'type' => 'highlight',
+					'id' => (string)$subjectParams['acl']['participant'],
 					'name' => $subjectParams['acl']['participant']
 				];
 			}
@@ -298,7 +310,7 @@ class DeckProvider implements IProvider {
 				$event->setParsedMessage($comment->getMessage());
 				$params['comment'] = [
 					'type' => 'highlight',
-					'id' => $subjectParams['comment'],
+					'id' => (string)$subjectParams['comment'],
 					'name' => $comment->getMessage()
 				];
 			} catch (NotFoundException $e) {
@@ -347,28 +359,28 @@ class DeckProvider implements IProvider {
 		if (array_key_exists('before', $subjectParams)) {
 			$params['before'] = [
 				'type' => 'highlight',
-				'id' => $subjectParams['before'],
-				'name' => $subjectParams['before']
+				'id' => (string)$subjectParams['before'],
+				'name' => $subjectParams['before'] ?? ''
 			];
 		}
 		if (array_key_exists('after', $subjectParams)) {
 			$params['after'] = [
 				'type' => 'highlight',
-				'id' => $subjectParams['after'],
-				'name' => $subjectParams['after']
+				'id' => (string)$subjectParams['after'],
+				'name' => $subjectParams['after'] ?? ''
 			];
 		}
 		if (array_key_exists('card', $subjectParams) && $event->getSubject() === ActivityManager::SUBJECT_CARD_UPDATE_TITLE) {
 			$params['card'] = [
 				'type' => 'highlight',
-				'id' => $subjectParams['after'],
-				'name' => $subjectParams['after']
+				'id' => (string)$subjectParams['after'],
+				'name' => $subjectParams['after'] ?? ''
 			];
 		}
 		return $params;
 	}
 
 	public function deckUrl($endpoint) {
-		return $this->urlGenerator->linkToRouteAbsolute('deck.page.index') . '#' . $endpoint;
+		return $this->urlGenerator->linkToRouteAbsolute('deck.page.index') . trim($endpoint, '/');
 	}
 }
