@@ -7,6 +7,20 @@
 
 namespace OCA\Deck\Db;
 
+/**
+ * @method int getBoardId()
+ * @method bool isPermissionEdit()
+ * @method void setPermissionEdit(bool $permissionEdit)
+ * @method bool isPermissionShare()
+ * @method void setPermissionShare(bool $permissionShare)
+ * @method bool isPermissionManage()
+ * @method void setPermissionManage(bool $permissionManage)
+ * @method int getType()
+ * @method void setType(int $type)
+ * @method bool isOwner()
+ * @method void setOwner(int $owner)
+ *
+ */
 class Acl extends RelationalEntity {
 	public const PERMISSION_READ = 0;
 	public const PERMISSION_EDIT = 1;
@@ -37,17 +51,13 @@ class Acl extends RelationalEntity {
 		$this->addResolvable('participant');
 	}
 
-	public function getPermission($permission) {
-		switch ($permission) {
-			case self::PERMISSION_READ:
-				return true;
-			case self::PERMISSION_EDIT:
-				return $this->getPermissionEdit();
-			case self::PERMISSION_SHARE:
-				return $this->getPermissionShare();
-			case self::PERMISSION_MANAGE:
-				return $this->getPermissionManage();
-		}
-		return false;
+	public function getPermission(int $permission): bool {
+		return match ($permission) {
+			self::PERMISSION_READ => true,
+			self::PERMISSION_EDIT => $this->getPermissionEdit(),
+			self::PERMISSION_SHARE => $this->getPermissionShare(),
+			self::PERMISSION_MANAGE => $this->getPermissionManage(),
+			default => false,
+		};
 	}
 }
