@@ -8,22 +8,25 @@
 
 namespace OCA\Deck\Db;
 
+/**
+ *
+ */
 interface IPermissionMapper {
 
 	/**
 	 * Check if $userId is owner of Entity with $id
 	 *
 	 * @param $userId string userId
-	 * @param $id int|string unique entity identifier
+	 * @param $id int unique entity identifier
 	 * @return boolean
 	 */
-	public function isOwner($userId, $id): bool;
+	public function isOwner(string $userId, int $id): bool;
 
 	/**
 	 * Query boardId for Entity of given $id
 	 *
-	 * @param $id int|string unique entity identifier
-	 * @return int|null id of Board
+	 * @param $id int unique entity identifier
+	 * @return ?int id of Board
 	 */
-	public function findBoardId($id): ?int;
+	public function findBoardId(int $id): ?int;
 }
