@@ -1,24 +1,8 @@
 <?php
+
 /**
- * @copyright Copyright (c) 2018 Julius Härtl <jus@bitgrid.net>
- *
- * @author Julius Härtl <jus@bitgrid.net>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2018 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Deck\Service;
@@ -26,6 +10,7 @@ namespace OCA\Deck\Service;
 use OCA\Deck\Activity\ActivityManager;
 use OCA\Deck\AppInfo\Application;
 use OCA\Deck\BadRequestException;
+use OCA\Deck\Cache\AttachmentCacheHelper;
 use OCA\Deck\Db\Acl;
 use OCA\Deck\Db\Attachment;
 use OCA\Deck\Db\AttachmentMapper;
@@ -34,13 +19,13 @@ use OCA\Deck\Db\ChangeHelper;
 use OCA\Deck\InvalidAttachmentType;
 use OCA\Deck\NoPermissionException;
 use OCA\Deck\NotFoundException;
-use OCA\Deck\Cache\AttachmentCacheHelper;
 use OCA\Deck\StatusException;
 use OCA\Deck\Validators\AttachmentServiceValidator;
 use OCP\AppFramework\Db\IMapperException;
 use OCP\AppFramework\Http\Response;
 use OCP\IL10N;
 use OCP\IUserManager;
+use Psr\Container\ContainerExceptionInterface;
 
 class AttachmentService {
 	private $attachmentMapper;
@@ -75,7 +60,7 @@ class AttachmentService {
 		$userId,
 		IL10N $l10n,
 		ActivityManager $activityManager,
-		AttachmentServiceValidator $attachmentServiceValidator
+		AttachmentServiceValidator $attachmentServiceValidator,
 	) {
 		$this->attachmentMapper = $attachmentMapper;
 		$this->cardMapper = $cardMapper;
@@ -96,20 +81,16 @@ class AttachmentService {
 	}
 
 	/**
-	 * @param string $type
-	 * @param string $class
-	 * @throws \OCP\AppFramework\QueryException
+	 * @throws ContainerExceptionInterface
 	 */
-	public function registerAttachmentService($type, $class) {
-		$this->services[$type] = $this->application->getContainer()->query($class);
+	public function registerAttachmentService(string $type, string $class): void {
+		$this->services[$type] = $this->application->getContainer()->get($class);
 	}
 
 	/**
-	 * @param string $type
-	 * @return IAttachmentService
 	 * @throws InvalidAttachmentType
 	 */
-	public function getService($type) {
+	public function getService(string $type): IAttachmentService {
 		if (isset($this->services[$type])) {
 			return $this->services[$type];
 		}
@@ -117,16 +98,11 @@ class AttachmentService {
 	}
 
 	/**
-	 * @param $cardId
-	 * @return array
+	 * @return Attachment[]
 	 * @throws \OCA\Deck\NoPermissionException
 	 * @throws BadRequestException
 	 */
-	public function findAll($cardId, $withDeleted = false) {
-		if (is_numeric($cardId) === false) {
-			throw new BadRequestException('card id must be a number');
-		}
-
+	public function findAll(int $cardId, bool $withDeleted = false): array {
 		$this->permissionService->checkPermission($this->cardMapper, $cardId, Acl::PERMISSION_READ);
 
 		$attachments = $this->attachmentMapper->findAll($cardId);
@@ -138,7 +114,7 @@ class AttachmentService {
 			/** @var IAttachmentService $service */
 			$service = $this->getService($attachmentType);
 			if ($service instanceof ICustomAttachmentService) {
-				$attachments = array_merge($attachments, $service->listAttachments((int)$cardId));
+				$attachments = array_merge($attachments, $service->listAttachments($cardId));
 			}
 		}
 
@@ -156,49 +132,40 @@ class AttachmentService {
 	}
 
 	/**
-	 * @param $cardId
-	 * @return int|mixed
 	 * @throws BadRequestException
 	 * @throws InvalidAttachmentType
 	 * @throws \OCP\DB\Exception
 	 */
-	public function count($cardId) {
-		if (is_numeric($cardId) === false) {
-			throw new BadRequestException('card id must be a number');
-		}
-
-		$count = $this->attachmentCacheHelper->getAttachmentCount((int)$cardId);
+	public function count(int $cardId): int {
+		$count = $this->attachmentCacheHelper->getAttachmentCount($cardId);
 		if ($count === null) {
 			$count = count($this->attachmentMapper->findAll($cardId));
 
 			foreach (array_keys($this->services) as $attachmentType) {
 				$service = $this->getService($attachmentType);
 				if ($service instanceof ICustomAttachmentService) {
-					$count += $service->getAttachmentCount((int)$cardId);
+					$count += $service->getAttachmentCount($cardId);
 				}
 			}
 
-			$this->attachmentCacheHelper->setAttachmentCount((int)$cardId, $count);
+			$this->attachmentCacheHelper->setAttachmentCount($cardId, $count);
 		}
 
 		return $count;
 	}
 
 	/**
-	 * @param $cardId
-	 * @param $type
-	 * @param $data
 	 * @return Attachment|\OCP\AppFramework\Db\Entity
 	 * @throws NoPermissionException
 	 * @throws StatusException
 	 * @throws BadRequestException
 	 */
-	public function create($cardId, $type, $data) {
+	public function create(int $cardId, string $type, string $data) {
 		$this->attachmentServiceValidator->check(compact('cardId', 'type'));
 
 		$this->permissionService->checkPermission($this->cardMapper, $cardId, Acl::PERMISSION_EDIT);
 
-		$this->attachmentCacheHelper->clearAttachmentCount((int)$cardId);
+		$this->attachmentCacheHelper->clearAttachmentCount($cardId);
 		$attachment = new Attachment();
 		$attachment->setCardId($cardId);
 		$attachment->setType($type);
@@ -234,12 +201,10 @@ class AttachmentService {
 	/**
 	 * Display the attachment
 	 *
-	 * @param $attachmentId
-	 * @return Response
 	 * @throws NoPermissionException
 	 * @throws NotFoundException
 	 */
-	public function display($cardId, $attachmentId, $type = 'deck_file') {
+	public function display(int $cardId, int $attachmentId, string $type = 'deck_file'): Response {
 		try {
 			$service = $this->getService($type);
 		} catch (InvalidAttachmentType $e) {
@@ -273,13 +238,10 @@ class AttachmentService {
 	/**
 	 * Update an attachment with custom data
 	 *
-	 * @param $attachmentId
-	 * @param $data
-	 * @return mixed
 	 * @throws BadRequestException
 	 * @throws NoPermissionException
 	 */
-	public function update($cardId, $attachmentId, $data, $type = 'deck_file') {
+	public function update(int $cardId, int $attachmentId, string $data, string $type = 'deck_file'): Attachment {
 		$this->attachmentServiceValidator->check(compact('cardId', 'type', 'data'));
 
 		try {
@@ -400,8 +362,6 @@ class AttachmentService {
 	}
 
 	/**
-	 * @param Attachment $attachment
-	 * @return Attachment
 	 * @throws \ReflectionException
 	 */
 	private function addCreator(Attachment $attachment): Attachment {
