@@ -1,4 +1,5 @@
 <?php
+
 /**
  * SPDX-FileCopyrightText: 2020 Nextcloud GmbH and Nextcloud contributors
  * SPDX-License-Identifier: AGPL-3.0-or-later
@@ -65,7 +66,7 @@ class CirclesService {
 			$circlesManager->startSession($federatedUser);
 			$circle = $circlesManager->getCircle($circleId);
 			$member = $circle->getInitiator();
-			$isUserInCircle = $member !== null && $member->getLevel() >= Member::LEVEL_MEMBER;
+			$isUserInCircle = $member->getLevel() >= Member::LEVEL_MEMBER;
 
 			if (!isset($this->userCircleCache[$circleId])) {
 				$this->userCircleCache[$circleId] = [];
